Versioned

Struct Versioned 

pub struct Versioned<T, const CURRENT: usize>(pub T);
A versioned setting field. If the current version does not match the version read, it resets the value to its default automatically and writes it to the file as well. Takes the form Versioned<[type], [current version]>.

Tuple Fields

0: T